@@ -9,7 +9,7 @@ u"""
 
     各コマンドモジュールは共通インターフェースとして
     Command クラスを持ちます。
-    
+
 ===============================
 """
 import os
@@ -25,27 +25,35 @@ from shimehari.core.manage import CreatableCommand
 from shimehari.helpers import getEnviron
 from shimehari.configuration import ConfigManager, Config
 
+
 u"""
 ===============================
     ::pkg:: Shimehari.core.manage.commands.generate
     Command
     ~~~~~~~
-    
+
     コマンドの実装
-    
+
 ===============================
 """
+
+
 class Command(CreatableCommand):
-    help = ("Generate Shimehari Modules")
+    name = 'generate'
+    summary = 'Generate Shimehari Modules'
+    usage = "Usage: %prog MODULE_NAME [OPTIONS]"
+
     option_list = CreatableCommand.option_list + (
-            make_option('--path', '-p', action='store', type='string', dest='path', help='generating target path'),
-            make_option('--namespace', '-ns', action='store', type='string', dest='prefix', help='prefix generetiong target path')
-        )
+        make_option('--path', '-p', action='store', type='string', dest='path', help='generating target path'),
+    )
+
+    def __init__(self):
+        super(Command, self).__init__()
 
     def handle(self, moduleType, name, *args, **options):
         if not moduleType == 'controller':
             raise CommandError('ない')
-    
+
         path = options.get('path')
         if path is None:
             currentPath = os.getcwd()
@@ -61,25 +69,17 @@ class Command(CreatableCommand):
             path = os.path.join(currentPath, config['APP_DIRECTORY'], config['CONTROLLER_DIRECTORY'])
 
         if not os.path.isdir(path):
-           raise CommandError('Given path is invalid')
+            raise CommandError('Given path is invalid')
 
-        prefix = options.get('prefix')
-        if prefix is not None:
-            path = prefix + path
-            #うーむ
-            #os.path.join(path,prefix)
+        ctrlTemplate = os.path.join(shimehari.__path__[0], 'core', 'conf', 'controller_template.org.py')
 
-        ctrlTemplate = os.path.join(shimehari.__path__[0], 'core','conf', 'controller_template.org.py')
-        
-        name, filename = self.filenameValidation(name)
-        newPath = os.path.join(path,filename)
+        name, filename = self.filenameValidation(path, name)
+        newPath = os.path.join(path, filename)
 
         self.readAndCreateFileWithRename(ctrlTemplate, newPath, name)
 
-
-
-    def filenameValidation(self, name):
-        if name.endswith(('.pyc','.pyo', '.py.class')):
+    def filenameValidation(self, path, name):
+        if name.endswith(('.pyc', '.pyo', '.py.class')):
             raise CommandError('invalid name....')
         if not name.endswith('.py'):
             filename = name + '.py'
@@ -87,27 +87,43 @@ class Command(CreatableCommand):
             filename = name
             name = name.replace('.py', '')
 
+        name = self.checkDirectory(path, name)
+
         import re
         if re.search(r"\W", name) or re.match(r"\d", name[0]):
             raise CommandError('file name is invalid')
         name = name[0].upper() + name[1:]
         return name, filename
 
+    def checkDirectory(self, path, name):
+        sep = None
+        if '.' in name:
+            sep = '.'
+        elif '/' in name:
+            sep = '/'
+        else:
+            pass
 
+        if sep is not None:
+            names = name.split(sep)
+        name = names.pop()
+        d = "/".join(names)
+        td = os.path.join(path, d)
+        if not os.path.isdir(td):
+            try:
+                os.makedirs(td)
+            except (IOError, OSError), e:
+                raise CommandError('invaild name... %s' % e)
+        return name
 
-    u"""-----------------------------
-        ::pkg:: Shimehari.core.manage.commands.generate.Command
-        readAndCreateFileWithRename
-        ~~~~~~~~~~~~~~~~~~~~~~~~~~~
-
-        指定されたディレクトリからテンプレートファイルを読み込み
-        新たに生成したい指定ディレクトリへファイルを生成します。
-        [args]
-            :old テンプレートファイルのパス
-            :new 生成したいディレクトリへのパスとファイル名
-            :name 変更したいクラス名
-    ------------------------------"""
     def readAndCreateFileWithRename(self, old, new, name):
+        u"""指定されたディレクトリからテンプレートファイルを読み込み
+        新たに生成したい指定ディレクトリへファイルを生成します。
+
+        :param old: テンプレートファイルのパス
+        :param new: 生成したいディレクトリへのパスとファイル名
+        :param name: 変更したいクラス名
+        """
         if os.path.exists(new):
             raise CommandError('Controller already exists.')
 
@@ -116,13 +132,15 @@ class Command(CreatableCommand):
             if '%s' in content:
                 content = content % name
                 content = content[3:]
-                content = content[:len(content) -3]
+                content = content[:len(content) - 3]
         with open(new, 'w') as newFile:
             newFile.write(content)
         sys.stdout.write("Genarating New Controller: %s\n" % new)
 
         try:
-            shutil.copymode(old,new)
+            shutil.copymode(old, new)
             self.toWritable(new)
         except OSError:
             sys.stderr.write('can not setting permission')
+
+Command()
