@@ -8,7 +8,8 @@ u"""
     ルーティング周り
 ===============================
 """
-import re, sys
+import re
+import sys
 from werkzeug.routing import Map, Rule, RuleTemplate
 
 from shimehari.controllers import AbstractController
@@ -25,13 +26,17 @@ u"""
     ルーター
 ===============================
 """
+
+
 class AbstractRouter(Map):
-    def __init__(self,rules=[], defaultSubdomain='', charset='utf-8',
+    u"""Shimehari アプリケーションで使用するルーターの抽象クラス
+    """
+    def __init__(self, rules=[], defaultSubdomain='', charset='utf-8',
                 strict_slashes=True, redirectDefaults=True,
                 converters=None, sortParameters=False, sortKey=None,
                 encodingErrors='replace', hostMatching=False):
 
-        Map.__init__(self, rules=rules,default_subdomain=defaultSubdomain, charset=charset,
+        Map.__init__(self, rules=rules, default_subdomain=defaultSubdomain, charset=charset,
                     strict_slashes=strict_slashes, redirect_defaults=redirectDefaults,
                     converters=converters, sort_parameters=sortParameters, sort_key=sortKey,
                     encoding_errors=encodingErrors, host_matching=hostMatching)
@@ -41,15 +46,10 @@ class AbstractRouter(Map):
         for rule in rules:
             self.add(rule)
 
-
-    u"""-----------------------------
-        Shimehari.AbstractRouter.dump
-        ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-        現在定義されているルーティングを出力します。
-        [return]
-            :str 定義されているルーティング
-    ------------------------------"""
     def dump(self):
+        u"""
+        現在定義されているルーティングを出力します。
+        """
         _map = ''
         for rule in self._rules:
             method = list(rule.methods.copy())
@@ -60,58 +60,32 @@ class AbstractRouter(Map):
             _map += '[action => '
             _map += rule.endpoint.__name__
             clsName = rule.endpoint.im_class.__name__
-            _map +=  ', controller => ' + clsName + ']\n'
+            _map += ', controller => ' + clsName + ']\n'
         return _map
 
 
-u"""
-===============================
-    Shimehari.routing.RESTfulRouter
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    リソースを指定して自動的にルーティング生成
-
-    Constructor
-
-    :resources
-        ルーティングを登録したいリソース。
-            => Shimehari.routing.Resource
-
-    :defaultSubdomain
-        prefix として指定するサブドメインを設定します。
-
-    :charset
-        文字コードを設定します。
-
-    :strictSlashes
-        ほげほげ
-
-    :redirectDefaults
-        ほげほげ
-
-    :converters
-        こんばーたーをしてい
-
-    :sortParameters
-        ほげほげ
-
-    :sortKey
-        ふがふが
-
-    :encordingErrors
-        ほげほげ
-
-    :hostMatching
-        ああああ
-
-===============================
-"""
 class RESTfulRouter(AbstractRouter):
+    u"""リソースを指定して自動的にルーティング生成
+
+
+    :param resources:           ルーティングを登録したいリソース。
+    :param defaultSubdomain:    prefix として指定するサブドメインを設定します。
+    :param charset:             文字コードを設定します。
+    :param strictSlashes:       ほげほげ
+    :param redirectDefaults:    ほげほげ
+    :param converters:          こんばーたーをしてい
+    :param sortParameters:      ほげほげ
+    :param sortKey:             ふがふが
+    :param encordingErrors:     ほげほげ
+    :param hostMatching:        ああああ
+
+    """
     def __init__(self, resources=[], defaultSubdomain='', charset='utf-8',
                 strict_slashes=True, redirectDefaults=True,
                 converters=None, sortParameters=False, sortKey=None,
                 encodingErrors='replace', hostMatching=False):
 
-        AbstractRouter.__init__(self, rules=[],defaultSubdomain=defaultSubdomain, charset=charset,
+        AbstractRouter.__init__(self, rules=[], defaultSubdomain=defaultSubdomain, charset=charset,
                     strict_slashes=strict_slashes, redirectDefaults=redirectDefaults,
                     converters=converters, sortParameters=sortParameters, sortKey=sortKey,
                     encodingErrors=encodingErrors, hostMatching=hostMatching)
@@ -119,7 +93,6 @@ class RESTfulRouter(AbstractRouter):
         self._rules = []
 
         for resource in resources:
-            rules = []
             if isinstance(resource, (Resource, RESTfulRule)):
                 for rule in resource._rules:
                     self.add(rule)
@@ -132,31 +105,13 @@ class RESTfulRouter(AbstractRouter):
                 raise TypeError('resources rule is invalid.')
 
 
-
 class Root(Rule):
     root = True
+
     def __init__(self, endpoint, methods=['get']):
         Rule.__init__(self, '/', endpoint=endpoint, methods=methods)
 
 
-
-u"""
-===============================
-
-    Shimehari.routing.RESTfulRule
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-    CRUD 準拠 URL ルール
-    こういうのはどうだろう…
-    :index
-        index
-    :show
-        show
-    :edit
-        edit
-
-===============================
-"""
-
 class RESTfulRule(object):
 
     parent = None
@@ -172,9 +127,9 @@ class RESTfulRule(object):
         if index is not None:
             rules.append(Rule(self.getName(name, 'index'), endpoint=index, methods=['get']))
         if show is not None:
-            rules.append(Rule(self.getName(name, 'show'), endpoint=show, methods=['get','post']))
+            rules.append(Rule(self.getName(name, 'show'), endpoint=show, methods=['get', 'post']))
         if edit is not None:
-            rules.append(Rule(self.getName(name, 'edit'), endpoint=edit, methods=['get','post']))
+            rules.append(Rule(self.getName(name, 'edit'), endpoint=edit, methods=['get', 'post']))
         if new is not None:
             rules.append(Rule(self.getName(name, 'new'), endpoint=new, methods=['get']))
         if create is not None:
@@ -185,20 +140,18 @@ class RESTfulRule(object):
             rules.append(Rule(self.getName(name, 'destroy'), endpoint=destroy, methods=['delete']))
         self._rules = rules
 
-
     def refresh(self):
         for rule in self._rules:
             if self.parent:
                 rule.rule = self.parent.baseName + '/' + rule.rule
             # rule.refresh()
 
-
     #uアクション名から URL Name を生成します
     def getNameFromRESTAction(self, name, action, root=False):
         if not name.startswith('/') and len(name) > 1:
             name = '/' + name
         if name.endswith('/') and len(name) > 1:
-            name = name[:len(name)-1]
+            name = name[:len(name) - 1]
 
         if root:
             name = ''
@@ -218,34 +171,26 @@ class RESTfulRule(object):
             raise ValueError('RESTfulRule')
 
 
-u"""
-===============================
-    Shimehari.routing.Resource
-    ~~~~~~~~~~~~~~~~~~~~~~~~~~
-    リソース
-    [args]
-    :controller
-        type::AbstractController or Dictionary
-        リソースとして指定するコントローラー
-
-
-===============================
-"""
 class Resource(Map):
+    u"""リソース
+
+    :param controller:  リソースとして指定するコントローラー
+    :param children:    aaa
+    :param name:        namae
+    :param only:
+
+    """
 
-    u"""親"""
     parent = None
 
-    u"""名前"""
     baseName = None
 
     orgName = None
 
-
-    def __init__(self, controller=None, children=[], name=None, only=[], excepts=[], root=False, 
+    def __init__(self, controller=None, children=[], name=None, only=[], excepts=[], root=False,
                 subdomain=None, buildOnly=False, strict_slashes=None, redirectTo=None,
                 alias=False, host=None, defaults=None, namespace=None):
-      
+
         Map.__init__(self, rules=[], default_subdomain='', charset='utf-8',
                  strict_slashes=True, redirect_defaults=True,
                  converters=None, sort_parameters=False, sort_key=None,
@@ -287,9 +232,9 @@ class Resource(Map):
             if self.namespace.startswith('/'):
                 self.namespace = self.namespace[1:]
             if self.namespace.endswith('/'):
-                self.namespace = self.namespace[:len(self.namespace)-1]
+                self.namespace = self.namespace[:len(self.namespace) - 1]
         #ディレクトリが深かった時自動で
-        elif controller is not None: 
+        elif controller is not None:
             config = ConfigManager.getConfig()
             if config['CONTROLLER_AUTO_NAMESPACE'] and type(controller) is not int:
                 pkgs = controller.__module__.split('.')
@@ -300,10 +245,10 @@ class Resource(Map):
                 if controllerFolder in pkgs:
                     pkgs.remove(controllerFolder)
 
-                self.orgName = pkgs[len(pkgs)-1]
-                pkgs = pkgs[:len(pkgs)-1]
+                self.orgName = pkgs[len(pkgs) - 1]
+                pkgs = pkgs[:len(pkgs) - 1]
                 self.namespace = "/".join(pkgs)
-            
+
         if controller:
             controller = self._checkControllerType(controller)
             if not name:
@@ -329,7 +274,6 @@ class Resource(Map):
                 if isinstance(child, Resource):
                     self._rules = self._rules + child._rules
 
-
     def _checkControllerType(self, controller):
         from shimehari.controllers import AbstractController
         if isinstance(controller, str):
@@ -350,23 +294,11 @@ class Resource(Map):
         return controller
 
     #みなおし
-    u"""----------------------------------------
-
-        [private]
-        ::pkg:: Shimehari.routing
-        _addRuleFromController
-        ~~~~~~~~~~~~~~~~~~~~~~
-        渡されたコントローラーから URL ルールを生成、追加します。
-
-        [args]
-            :controller ルールを追加したいコントローラー
-
-    ---------------------------------------------"""
     def _addRuleFromController(self, controller):
         actions = RESTFUL_ACTIONS.copy()
         if self.only is not None:
             actions = RESTFUL_ACTIONS.intersection(self.only)
-        if self.excepts is not None:    
+        if self.excepts is not None:
             actions = RESTFUL_ACTIONS.difference(self.excepts)
 
         for action in actions:
@@ -375,45 +307,26 @@ class Resource(Map):
                 name = self.getName(self.baseName, action, self.root)
 
                 methods = RESTFUL_METHODS_MAP[action.lower()]
-                rule = Rule(name, defaults=self.defaults, endpoint=handler, 
+                rule = Rule(name, defaults=self.defaults, endpoint=handler,
                             subdomain=self.subdomain, methods=methods, build_only=self.buildOnly,
                             strict_slashes=self.strict_slashes, redirect_to=self.redirectTo, alias=self.alias, host=self.host)
 
                 self._rules.append(rule)
 
-
-
-    u"""----------------------------------------
-
-        _addRuleFromRules
-        ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
-        Rule が格納されたディクショナリをルールに追加します。
-
-        [args]
-            :rules 追加したい Rule を格納したディクショナリ
-
-    ---------------------------------------------"""
     def _addRuleFromRules(self, rules):
         for rule in rules:
-            if not isinstance(rule, RuleBase):
+            if not isinstance(rule, Rule):
                 raise TypeError('Rule type is invalid')
             self._rules.append(rule)
 
+    def add(self, controller):
+        u"""コントローラー、もしくはルールを追加します。
 
-    #aaaaa
-    u"""----------------------------------------
 
-        add
-        ~~~
-        
-        コントローラー、もしくはルールを追加します。
-        [args]
-            :controller 
-                ルールを追加したいコントローラー、もしくは
-                RESTfulRule、ルールを格納したディクショナリ
+        :param controller:  ルールを追加したいコントローラー、もしくは
+                            RESTfulRule、ルールを格納したディクショナリ
 
-    ---------------------------------------------"""
-    def add(self,controller):
+        """
         import inspect
         if inspect.isclass(controller):
             controller = controller(controller.__name__)
@@ -427,16 +340,20 @@ class Resource(Map):
         else:
             raise ValueError('out!')
 
-
     def refresh(self):
         for rule in self._rules:
             if self.parent:
                 rule.rule = '/' + self.parent.baseName + rule.rule
 
-
-
     def addRule(self, name, handler, methods=[], *args, **kwargs):
-        rule = Rule(name, defaults=self.defaults, endpoint=handler, 
+        u"""リソースに対してルールを追加します。
+
+        :param name:        名前
+        :param handler:     処理
+        :param methods:     使用する HTTP メソッド
+
+        """
+        rule = Rule(name, defaults=self.defaults, endpoint=handler,
                             subdomain=self.subdomain, methods=methods, build_only=self.buildOnly,
                             strict_slashes=self.strict_slashes, redirect_to=self.redirectTo, alias=self.alias, host=self.host)
         self._rules.append(rule)
@@ -447,19 +364,24 @@ class Resource(Map):
     def overRideRule(self, action, name, handler=None, methods=[], *args, **kwargs):
         print self._rules
 
-
-    u"""アクション名から URL Name を生成します"""
     def getNameFromRESTAction(self, name, action, root=False):
+        u"""アクション名から URL Name を生成します。
+
+        :param name:    名前
+        :param action:  アクション
+        :param root:    ルートかどうか
+        """
+
         if self.namespace:
             name = self.namespace + '/' + name
 
         if not name.startswith('/') and len(name) > 1:
             name = '/' + name
         if name.endswith('/') and len(name) > 1:
-            name = name[:len(name)-1]
+            name = name[:len(name) - 1]
 
         if root:
-            name = '' 
+            name = ''
 
         _act = action.lower()
         if _act == 'index' or _act == 'create':
@@ -479,6 +401,8 @@ class Resource(Map):
 u"""
 werkzeug の中に似たのがあるっぽい…
 """
+
+
 class Group(object):
     def __init__(self, name, children):
         for child in children:
@@ -493,7 +417,5 @@ class Group(object):
                 raise RuntimeError('settei dekimasen.')
 
 
-
-
 #defaultRouterClass
-Router = RESTfulRouter
\ No newline at end of file
+Router = RESTfulRouter
